==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/BulkAudio.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[BulkAudio]
AS
BEGIN
	-- EMULAMOS UNA NUEVA TABLA EN BASE A #AudioTemp DONDE SE REMOVERAN TODOS LOS REGISTROS DUPLICADOS PARA EL PK DE LA TABLA Audio
	WITH CTE AS (
	   SELECT A.[VCC], A.[ID], A.[Section], A.[Part], A.[Number],
				A.[Gender], A.[SilenceTime], A.[DurationTime], A.[Category1], A.[Category2],
				A.[Category3], A.[Description], A.[Campaign], A.[Agent], A.[Type],
				A.[Init], A.[StartDate], A.[EndDate], A.[DispositionCode], A.[CreatedDate],
				A.[CreatedByUserId], A.[LastModifiedDate], A.[LastModifiedByUserId], RN = ROW_NUMBER() OVER(PARTITION BY A.[VCC], A.[ID], A.[Section], A.[Part] ORDER BY A.[ID])
	   FROM #AudioTemp A (NOLOCK)
	)
	-- LA TABLA TEMPORAL #AudioTemp LLEGA CON ALGUNOS REGISTROS DUPLICADOS DEBIDO A LOS CRUCES AL APLICAR LOR FILTROS, POR ELLO DEBEMOS 
	-- IDENTIFICAR LOS REPETIDOS, RN = ROW_NUMBER() OVER(PARTITION BY ...) <- NUMERA CADA REGISTRO SEGUN EL(LOS) VALOR(ES) DE ...

	-- EL CTE SOLO PUEDE SER INVOCADO UNA VEZ POR ESO LO PONEMOS EN EL SELECT FINAL DONDE EL CONTADOR(RN) ES 1
	--DELETE FROM CTE WHERE RN > 1

	INSERT INTO dbo.Audio(
			[VCC]
			,[ID]
			,[Section]
			,[Part]
			,[Number]
			,[Gender]
			,[SilenceTime]
			,[DurationTime]
			,[Category1]
			,[Category2]
			,[Category3]
			,[Description]
			,[Campaign]
			,[Agent]
			,[Type]
			,[Init]
			,[StartDate]
			,[EndDate]
			,[DispositionCode]
			,[CreatedDate]
			,[CreatedByUserId]
			,[LastModifiedDate]
			,[LastModifiedByUserId]
			,[TimeStamp]
			) 
		SELECT
			 A.[VCC]
			,A.[ID]
			,A.[Section]
			,A.[Part]
			,A.[Number]
			,A.[Gender]
			,A.[SilenceTime]
			,A.[DurationTime]
			,A.[Category1]
			,A.[Category2]
			,A.[Category3]
			,A.[Description]
			,A.[Campaign]
			,A.[Agent]
			,A.[Type]
			,A.[Init]
			,A.[StartDate]
			,A.[EndDate]
			,A.[DispositionCode]
			,A.[CreatedDate]
			,A.[CreatedByUserId]
			,A.[LastModifiedDate]
			,A.[LastModifiedByUserId]
			,GETUTCDATE()
		FROM CTE A (NOLOCK)
		WHERE A.RN = 1
			AND NOT EXISTS (
			SELECT * FROM Audio B (NOLOCK)
			WHERE B.[VCC] = A.[VCC]
			AND B.[ID] = A.[ID]
			AND B.[Section] = A.[Section]
			AND B.[Part] = A.[Part]
		);

	-- EMULAMOS UNA NUEVA TABLA EN BASE A #AudioTemp DONDE SE REMOVERAN TODOS LOS REGISTROS DUPLICADOS PARA EL PK DE LA TABLA Audio
	WITH CTE_PAT AS (
	   SELECT PAT.[VCC], PAT.[ProcessId], PAT.[AudioId], PAT.[Section], PAT.[Part]
			,PAT.[CreatedDate], PAT.[CreatedByUserId], PAT.[LastModifiedDate], PAT.[LastModifiedByUserId], RN = ROW_NUMBER() OVER(PARTITION BY PAT.[VCC], PAT.[ProcessId], PAT.[AudioId], PAT.[Section], PAT.[Part] ORDER BY PAT.[AudioId])
	   FROM #ProcessAudioTemp PAT (NOLOCK)
	)
	-- EL CTE_PAT SOLO PUEDE SER INVOCADO UNA VEZ POR ESO LO PONEMOS EN EL SELECT FINAL DONDE EL CONTADOR(RN) ES 1
	--DELETE FROM CTE_PAT WHERE RN > 1
		
	-- Insertamos registros en la tabla ProcessAudio
	INSERT INTO dbo.ProcessAudio
			([VCC]
			,[ProcessId]
			,[AudioId]
			,[Section]
			,[Part]
			,[CreatedDate]
			,[CreatedByUserId]
			,[LastModifiedDate]
			,[LastModifiedByUserId]
			,[TimeStamp]
			) 
		SELECT
			 PAT.[VCC]
			,PAT.[ProcessId]
			,PAT.[AudioId]
			,PAT.[Section]
			,PAT.[Part]
			,PAT.[CreatedDate]
			,PAT.[CreatedByUserId]
			,PAT.[CreatedDate]
			,PAT.[CreatedByUserId]
			,GETUTCDATE()
		FROM CTE_PAT PAT (NOLOCK)
		WHERE PAT.RN = 1
			AND NOT EXISTS (
			SELECT * FROM ProcessAudio PA (NOLOCK)
			WHERE PA.[VCC] = PAT.[VCC]
			AND PA.[ProcessId] = PAT.[ProcessId]
			AND PA.[AudioId] = PAT.[AudioId]
			AND PA.[Section] = PAT.[Section]
			AND PA.[Part] = PAT.[Part]
		)
		GROUP BY 
			PAT.[VCC]
			,PAT.[ProcessId]
			,PAT.[AudioId]
			,PAT.[Section]
			,PAT.[Part]
			,PAT.[CreatedByUserId]
			,PAT.[CreatedDate]

		DROP TABLE #AudioTemp
		DROP TABLE #ProcessAudioTemp

END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_0.15.1_database.tar.gz: database/mssql/procedures/BulkAudio.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[BulkAudio]
AS
BEGIN
	-- EMULAMOS UNA NUEVA TABLA EN BASE A #AudioTemp DONDE SE REMOVERAN TODOS LOS REGISTROS DUPLICADOS PARA EL PK DE LA TABLA Audio
	WITH CTE AS (
		SELECT A.[VCC], A.[ID], A.[Section], A.[Part], A.[Number],
				A.[Gender], A.[SilenceTime], A.[DurationTime], A.[Category1], A.[Category2],
				A.[Category3], A.[Description], A.[Campaign], A.[Agent], AG.[Name] 'AgentName',
				A.[Type], A.[Init], A.[StartDate], A.[EndDate], A.[DispositionCode], 
				A.[CreatedDate], A.[CreatedByUserId], A.[LastModifiedDate], A.[LastModifiedByUserId], RN = ROW_NUMBER() OVER(PARTITION BY A.[VCC], A.[ID], A.[Section], A.[Part] ORDER BY A.[ID])
	    FROM #AudioTemp A (NOLOCK)
	    LEFT JOIN [dbo].[Agent] AG (NOLOCK)
			ON AG.[VCC] = A.[VCC]
				AND AG.[AgentId] = A.[Agent]
	)
	-- LA TABLA TEMPORAL #AudioTemp LLEGA CON ALGUNOS REGISTROS DUPLICADOS DEBIDO A LOS CRUCES AL APLICAR LOR FILTROS, POR ELLO DEBEMOS 
	-- IDENTIFICAR LOS REPETIDOS, RN = ROW_NUMBER() OVER(PARTITION BY ...) <- NUMERA CADA REGISTRO SEGUN EL(LOS) VALOR(ES) DE ...

	-- EL CTE SOLO PUEDE SER INVOCADO UNA VEZ POR ESO LO PONEMOS EN EL SELECT FINAL DONDE EL CONTADOR(RN) ES 1
	--DELETE FROM CTE WHERE RN > 1

	INSERT INTO dbo.Audio(
			[VCC]
			,[ID]
			,[Section]
			,[Part]
			,[Number]
			,[Gender]
			,[SilenceTime]
			,[DurationTime]
			,[Category1]
			,[Category2]
			,[Category3]
			,[Description]
			,[Campaign]
			,[Agent]
			,[AgentName]
			,[Type]
			,[Init]
			,[StartDate]
			,[EndDate]
			,[DispositionCode]
			,[CreatedDate]
			,[CreatedByUserId]
			,[LastModifiedDate]
			,[LastModifiedByUserId]
			,[TimeStamp]
			) 
		SELECT
			 A.[VCC]
			,A.[ID]
			,A.[Section]
			,A.[Part]
			,A.[Number]
			,A.[Gender]
			,A.[SilenceTime]
			,A.[DurationTime]
			,A.[Category1]
			,A.[Category2]
			,A.[Category3]
			,A.[Description]
			,A.[Campaign]
			,A.[Agent]
			,A.[AgentName]
			,A.[Type]
			,A.[Init]
			,A.[StartDate]
			,A.[EndDate]
			,A.[DispositionCode]
			,A.[CreatedDate]
			,A.[CreatedByUserId]
			,A.[LastModifiedDate]
			,A.[LastModifiedByUserId]
			,GETUTCDATE()
		FROM CTE A (NOLOCK)
		WHERE A.RN = 1
			AND NOT EXISTS (
			SELECT * FROM Audio B (NOLOCK)
			WHERE B.[VCC] = A.[VCC]
			AND B.[ID] = A.[ID]
			AND B.[Section] = A.[Section]
			AND B.[Part] = A.[Part]
		);

	-- EMULAMOS UNA NUEVA TABLA EN BASE A #AudioTemp DONDE SE REMOVERAN TODOS LOS REGISTROS DUPLICADOS PARA EL PK DE LA TABLA Audio
	WITH CTE_PAT AS (
	   SELECT PAT.[VCC], PAT.[ProcessId], PAT.[AudioId], PAT.[Section], PAT.[Part]
			,PAT.[CreatedDate], PAT.[CreatedByUserId], PAT.[LastModifiedDate], PAT.[LastModifiedByUserId], RN = ROW_NUMBER() OVER(PARTITION BY PAT.[VCC], PAT.[ProcessId], PAT.[AudioId], PAT.[Section], PAT.[Part] ORDER BY PAT.[AudioId])
	   FROM #ProcessAudioTemp PAT (NOLOCK)
	)
	-- EL CTE_PAT SOLO PUEDE SER INVOCADO UNA VEZ POR ESO LO PONEMOS EN EL SELECT FINAL DONDE EL CONTADOR(RN) ES 1
	--DELETE FROM CTE_PAT WHERE RN > 1
		
	-- Insertamos registros en la tabla ProcessAudio
	INSERT INTO dbo.ProcessAudio
			([VCC]
			,[ProcessId]
			,[AudioId]
			,[Section]
			,[Part]
			,[CreatedDate]
			,[CreatedByUserId]
			,[LastModifiedDate]
			,[LastModifiedByUserId]
			,[TimeStamp]
			) 
		SELECT
			 PAT.[VCC]
			,PAT.[ProcessId]
			,PAT.[AudioId]
			,PAT.[Section]
			,PAT.[Part]
			,PAT.[CreatedDate]
			,PAT.[CreatedByUserId]
			,PAT.[CreatedDate]
			,PAT.[CreatedByUserId]
			,GETUTCDATE()
		FROM CTE_PAT PAT (NOLOCK)
		WHERE PAT.RN = 1
			AND NOT EXISTS (
			SELECT * FROM ProcessAudio PA (NOLOCK)
			WHERE PA.[VCC] = PAT.[VCC]
			AND PA.[ProcessId] = PAT.[ProcessId]
			AND PA.[AudioId] = PAT.[AudioId]
			AND PA.[Section] = PAT.[Section]
			AND PA.[Part] = PAT.[Part]
		)
		GROUP BY 
			PAT.[VCC]
			,PAT.[ProcessId]
			,PAT.[AudioId]
			,PAT.[Section]
			,PAT.[Part]
			,PAT.[CreatedByUserId]
			,PAT.[CreatedDate]

		DROP TABLE #AudioTemp
		DROP TABLE #ProcessAudioTemp

END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
